.. _reference:

*************
API Reference
*************

.. autosummary::
   :toctree: _autosummary
   :recursive:

   roentgen
   roentgen.absorption.material
   roentgen.lines.lines
   roentgen.util.util
   roentgen.nuclides.nuclides